@@ -1,5 +1,5 @@
 /*
- * $Id: dbdimp.h,v 1.7 1998/08/08 16:58:30 timbo Exp $
+ * $Id: dbdimp.h 87 2004-02-19 16:49:09Z jurl $
  * Copyright (c) 1997-2001 Jeff Urlwin
  * portions Copyright (c) 1997  Thomas K. Wenrich
  * portions Copyright (c) 1994,1995,1996  Tim Bunce
@@ -149,7 +149,10 @@ struct phs_st {  	/* scalar placeholder EXPERIMENTAL	*/
 #define dbd_init		odbc_init
 #define dbd_db_login		odbc_db_login
 #define dbd_db_login6		odbc_db_login6
-#define dbd_db_do		odbc_db_do
+/*
+ * Not defined by DBI
+ * #define dbd_db_do		odbc_db_do
+ */
 #define dbd_db_commit		odbc_db_commit
 #define dbd_db_rollback		odbc_db_rollback
 #define dbd_db_disconnect	odbc_db_disconnect
@@ -168,5 +171,5 @@ struct phs_st {  	/* scalar placeholder EXPERIMENTAL	*/
 #define dbd_describe		odbc_describe
 #define dbd_bind_ph		odbc_bind_ph
 #define dbd_error		odbc_error
-
+#define dbd_discon_all		odbc_discon_all
 /* end */
